@@ -194,7 +194,7 @@ derive_param_bsa <- function(dataset,
   )
 
   bsa_formula <- expr(
-    compute_bsa(
+    {{ compute_bsa }}(
       height = !!sym(paste0("AVAL.", height_code)),
       weight = !!sym(paste0("AVAL.", weight_code)),
       method = !!method
