@@ -58,6 +58,19 @@
 #'
 #' @permitted [condition]
 #'
+#' @param constant_values Constant variables to set
+#'
+#'   The specified variables are set to the specified values for all new
+#'   summary records, including those with data in `dataset_add` and those with
+#'   no data imputed using `dataset_ref` and `missing_values`.
+#'
+#'   Set a list of variables to some specified value for the new records
+#'   + LHS refer to a variable.
+#'   + RHS refers to the values to set to the variable. This can be an
+#'   expression.
+#'
+#' @permitted [expr_list_summary]
+#'
 #' @param set_values_to Variables to be set
 #'
 #'   The specified variables are set to the specified values for the new
@@ -68,6 +81,7 @@
 #'   + RHS refers to the values to set to the variable. This can be a string, a
 #'   symbol, a numeric value, an expression or NA. If summary functions are
 #'   used, the values are summarized by the variables specified for `by_vars`.
+#'   Any expression on the RHS must result in a single value per by group.
 #'
 #'   For example:
 #'   ```
@@ -92,7 +106,7 @@
 #' @family der_prm_bds_findings
 #' @keywords der_prm_bds_findings
 #'
-#' @seealso [derive_var_merged_summary()]
+#' @seealso [derive_vars_merged_summary()]
 #'
 #' @export
 #'
@@ -237,12 +251,64 @@
 #'   )
 #' ) %>%
 #'   arrange(USUBJID, AVISIT)
+#'
+#' @caption Add constant values to derived and missing summary records.
+#'
+#' @info The `constant_values` argument allows you to assign fixed, common values
+#' to all summary records generated by the function. This is particularly useful
+#' when you need to populate new information for observations derived from the
+#' `dataset_add` as well as for new records created for subjects present in
+#' `dataset_ref` but missing in `dataset_add`.
+#'
+#' For example, if `ADSL` contains two subjects ("1" and "2"), but `ADAE` only
+#' has adverse event information for "Subject 1", `derive_summary_records` will:
+#'
+#' 1. Create a summary record for "Subject 1" based on `ADAE`.
+#' 2. Identify "Subject 2" (from `ADSL`) as having no corresponding records in
+#' `ADAE` and create a new record for it.
+#'
+#' The `constant_values` argument ensures that all these generated summary records
+#' (for both Subject 1 and the newly created record for Subject 2) receive the
+#' same `PARAMCD`, `PARAM`, and `PARCAT1` values.
+#' Additionally, `missing_values` is used to specifically set `AVAL` to 0 for
+#' "Subject 2" when no adverse events are found.
+#'
+#'
+#' @code
+#' library(tibble)
+#'
+#' adsl <- tibble(USUBJID = c("1", "2"))
+#'
+#' adae <- tribble(
+#'  ~USUBJID, ~AEDECOD,
+#'  "1",      "Illness",
+#'  "1",      "Pain"
+#' )
+#'
+#' derive_summary_records(
+#'   dataset_add = adae,
+#'   dataset_ref = adsl,
+#'   by_vars = exprs(USUBJID),
+#'   constant_values = exprs(
+#'     PARAMCD = "AECOUNT",
+#'     PARAM = "Number of adverse events",
+#'     PARCAT1 = "Adverse events"
+#'   ),
+#'   set_values_to = exprs(
+#'     AVAL = n_distinct(AEDECOD),
+#'     SRCDOM = "ADAE"
+#'   ),
+#'   missing_values = exprs(
+#'     AVAL = 0
+#'   )
+#' )
 
 derive_summary_records <- function(dataset = NULL,
                                    dataset_add,
                                    dataset_ref = NULL,
                                    by_vars,
                                    filter_add = NULL,
+                                   constant_values = NULL,
                                    set_values_to,
                                    missing_values = NULL) {
   assert_vars(by_vars)
@@ -255,6 +321,7 @@ derive_summary_records <- function(dataset = NULL,
   )
 
   assert_varval_list(set_values_to)
+  assert_varval_list(constant_values, optional = TRUE)
   assert_expr_list(missing_values, named = TRUE, optional = TRUE)
 
   filter_add <- assert_filter_cond(enexpr(filter_add), optional = TRUE)
@@ -262,8 +329,28 @@ derive_summary_records <- function(dataset = NULL,
   summary_records <- dataset_add %>%
     group_by(!!!by_vars) %>%
     filter_if(filter_add) %>%
-    summarise(!!!set_values_to) %>%
-    ungroup()
+    reframe(!!!set_values_to)
+
+  signal_duplicate_records(
+    summary_records,
+    by_vars = by_vars,
+    msg = c(
+      paste(
+        "After summarising, the dataset contains mulitple records with",
+        "respect to {.var {by_vars}}."
+      ),
+      paste(
+        "Please check the {.arg set_values_to} argument if summary functions",
+        "like {.fun mean}, {.fun sum}, ... are used on the right hand side."
+      )
+    ),
+    class = "multiple_summary_records"
+  )
+
+  if (!is.null(constant_values)) {
+    summary_records <- summary_records %>%
+      mutate(!!!constant_values)
+  }
 
   df_return <- bind_rows(
     dataset,
@@ -282,6 +369,11 @@ derive_summary_records <- function(dataset = NULL,
         mutate(!!!missing_values)
     }
 
+    if (!is.null(constant_values)) {
+      new_ref_obs <- new_ref_obs %>%
+        mutate(!!!constant_values)
+    }
+
     df_return <- bind_rows(
       df_return,
       new_ref_obs
