@@ -38,6 +38,7 @@ globalVariables(c(
   "IDVAR",
   "IDVARVAL",
   "LSTALVDT",
+  "NFRLT",
   "ONTRTFL",
   "PARAMCD",
   "RANDDT",
@@ -61,6 +62,8 @@ globalVariables(c(
   "Dataset",
   "dataset_name",
   "datedtc___",
+  "day_diff",
+  "day_diff_adjusted",
   "Derivation",
   "Derivation / Comment",
   "desc",
