@@ -1,15 +1,15 @@
-test_that("new observations are derived correctly", {
+# derive_param_rr ----
+
+## Test 1: new observations are derived correctly ----
+test_that("derive_param_rr Test 1: new observations are derived correctly", {
   input <- tibble::tribble(
     ~USUBJID,      ~PARAMCD, ~PARAM,        ~AVAL, ~AVALU,      ~VISIT,
     "01-701-1015", "HR",     "Heart Rate",  70.14, "beats/min", "BASELINE",
-    "01-701-1015", "QT",     "QT Duration", 370,   "msec",      "WEEK 2",
     "01-701-1015", "HR",     "Heart Rate",  62.66, "beats/min", "WEEK 1",
-    "01-701-1015", "RR",     "RR Duration", 710,   "msec",      "WEEK 2",
+    "01-701-1015", "RR",     "RR Duration", 710,   "ms",        "WEEK 2",
     "01-701-1028", "HR",     "Heart Rate",  85.45, "beats/min", "BASELINE",
-    "01-701-1028", "QT",     "QT Duration", 480,   "msec",      "WEEK 2",
-    "01-701-1028", "QT",     "QT Duration", 350,   "msec",      "WEEK 3",
     "01-701-1028", "HR",     "Heart Rate",  56.54, "beats/min", "WEEK 3",
-    "01-701-1028", "RR",     "RR Duration", 842,   "msec",      "WEEK 2",
+    "01-701-1028", "RR",     "RR Duration", 842,   "ms",        "WEEK 2",
   )
 
   new_obs <- input %>%
@@ -18,8 +18,8 @@ test_that("new observations are derived correctly", {
     mutate(
       AVAL = 60000 / AVAL,
       PARAMCD = "RRR",
-      PARAM = "RR Duration Rederived (msec)",
-      AVALU = "msec"
+      PARAM = "RR Duration Rederived (ms)",
+      AVALU = "ms"
     )
   expected_output <- bind_rows(input, new_obs)
 
@@ -29,8 +29,8 @@ test_that("new observations are derived correctly", {
       by_vars = exprs(USUBJID, VISIT),
       set_values_to = exprs(
         PARAMCD = "RRR",
-        PARAM = "RR Duration Rederived (msec)",
-        AVALU = "msec"
+        PARAM = "RR Duration Rederived (ms)",
+        AVALU = "ms"
       ),
       get_unit_expr = AVALU
     ),
@@ -38,3 +38,33 @@ test_that("new observations are derived correctly", {
     keys = c("USUBJID", "PARAMCD", "VISIT")
   )
 })
+
+## Test 2: Message if no new records ----
+test_that("derive_param_rr Test 2: Message if no new records", {
+  input <- tibble::tribble(
+    ~USUBJID,      ~PARAMCD, ~PARAM,        ~AVAL, ~AVALU,      ~VISIT,
+    "01-701-1015", "HR",     "Heart Rate",     NA, "beats/min", "BASELINE",
+    "01-701-1015", "HR",     "Heart Rate",     NA, "beats/min", "WEEK 1",
+    "01-701-1015", "RR",     "RR Duration",   710, "ms",        "WEEK 2"
+  )
+
+
+  expect_snapshot(
+    actual <- derive_param_rr(
+      input,
+      by_vars = exprs(USUBJID, VISIT),
+      set_values_to = exprs(
+        PARAMCD = "RRR",
+        PARAM = "RR Duration Rederived (ms)",
+        AVALU = "ms"
+      ),
+      get_unit_expr = AVALU
+    )
+  )
+
+  expect_dfs_equal(
+    base = input,
+    compare = actual,
+    keys = c("USUBJID", "PARAMCD", "VISIT")
+  )
+})
